@@ -17,6 +17,10 @@
 # License along with python-fedora; if not, see <http://www.gnu.org/licenses/>
 #
 """
+DEPRECATED: This module is deprecated and has moved to bodhi.client.bindings.
+As the bodhi-0.9 client still uses it, it will remain here until Fedora 25 is
+EOL.
+
 This module provides a client interface for bodhi.
 
 
@@ -36,9 +40,14 @@ import re
 
 import six
 
-from fedora.client import OpenIdBaseClient, FedoraClientError, BaseClient
+from fedora.client import AuthError, OpenIdBaseClient, FedoraClientError, BaseClient
 import fedora.client.openidproxyclient
 
+
+warnings.warn('fedora.client.bodhi has been deprecated. Please use bodhi.client.bindings instead.',
+              DeprecationWarning)
+
+
 __version__ = '2.0.0'
 log = logging.getLogger(__name__)
 
@@ -79,7 +88,23 @@ def errorhandled(method):
     """ A decorator for Bodhi2Client that raises exceptions on failure. """
     @functools.wraps(method)
     def wrapper(*args, **kwargs):
-        result = method(*args, **kwargs)
+        try:
+            result = method(*args, **kwargs)
+        except AuthError:
+            # An AuthError can be raised for three different reasons:
+            #
+            # 0) The password is wrong.
+            # 1) The session cookies are expired. fedora.python does not handle this automatically.
+            # 2) The session cookies are not expired, but are no longer valid (for example, this can
+            #    happen if the server's auth secret has changed.)
+            #
+            # We don't know the difference between the cases, but case #1 is fairly common and we
+            # can work around it by removing the session cookies and csrf token and retrying the
+            # request. If the password is wrong, the second attempt will also fail but we won't
+            # guard it and the AuthError will still be raised.
+            args[0]._session.cookies.clear()
+            args[0].csrf_token = None
+            result = method(*args, **kwargs)
 
         if 'errors' not in result:
             return result
@@ -113,6 +138,10 @@ class Bodhi2Client(OpenIdBaseClient):
             self._password = getpass.getpass()
         return self._password
 
+    @password.setter
+    def password(self, value):
+        self._password = value
+
     @errorhandled
     def save(self, **kwargs):
         """ Save an update.
@@ -237,7 +266,7 @@ class Bodhi2Client(OpenIdBaseClient):
             # update ID, so try and figure it out
             if re.search(r'(\.el|\.fc)\d\d?', kwargs['package']):
                 kwargs['builds'] = kwargs['package']
-            elif re.search(r'FEDORA-(EPEL)?-\d{4,4}', kwargs['package']):
+            elif re.search(r'FEDORA-(EPEL-)?\d{4,4}', kwargs['package']):
                 kwargs['updateid'] = kwargs['package']
             else:
                 kwargs['packages'] = kwargs['package']
